MiPushMessageEntity class

Constructors

MiPushMessageEntity({bool? arrivedMessage, String? content, String? description, MiPushMessageExtra? extra, String? messageId, int? messageType, bool? notified, int? notifyId, int? notifyType, int? passThrough, String? title})
MiPushMessageEntity.fromJson(Map<String, dynamic> json)
factory

Properties

arrivedMessage → bool?
final
content → String?
final
description → String?
final
extra → MiPushMessageExtra?
final
hashCode → int
The hash code for this object.
no setterinherited
messageId → String?
final
messageType → int?
final
notified → bool?
final
notifyId → int?
final
notifyType → int?
final
passThrough → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited