MiPushMessageExtra class

Constructors

MiPushMessageExtra({String? highPriorityEvent, String? feTs, String? planId, String? source, String? notifyForeground, String? mTs})
MiPushMessageExtra.fromJson(Map<String, dynamic> json)
factory

Properties

feTs → String?
final
hashCode → int
The hash code for this object.
no setterinherited
highPriorityEvent → String?
final
mTs → String?
final
notifyForeground → String?
final
planId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited